package cn.com.infosec.ocsp;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.ocsp.ResponseData;
import cn.com.infosec.asn1.ocsp.SingleResponse;
import cn.com.infosec.asn1.x509.X509Extensions;
import java.io.ByteArrayOutputStream;
import java.security.cert.X509Extension;
import java.text.ParseException;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Set;

public class RespData implements X509Extension {
   ResponseData data;

   public RespData(ResponseData data) {
      this.data = data;
   }

   private Set getExtensionOIDs(boolean critical) {
      RespData var10000 = this;
      HashSet var5;
      var5 = new HashSet.<init>();
      X509Extensions var2;
      if ((var2 = var10000.getResponseExtensions()) != null) {
         Enumeration var3 = var2.oids();

         while(var3.hasMoreElements()) {
            DERObjectIdentifier var4;
            if (critical == var2.getExtension(var4 = (DERObjectIdentifier)var3.nextElement()).isCritical()) {
               var5.add(var4.getId());
            }
         }
      }

      return var5;
   }

   public int getVersion() {
      return this.data.getVersion().getValue().intValue() + 1;
   }

   public RespID getResponderId() {
      return new RespID(this.data.getResponderID());
   }

   public Date getProducedAt() {
      try {
         return this.data.getProducedAt().getDate();
      } catch (ParseException var1) {
         throw new IllegalStateException("ParseException:" + var1.getMessage());
      }
   }

   public SingleResp[] getResponses() {
      int var1;
      ASN1Sequence var5;
      SingleResp[] var2 = new SingleResp[var1 = (var5 = this.data.getResponses()).size()];

      for(int var3 = 0; var3 != var1; ++var3) {
         SingleResp var4;
         var4 = new SingleResp.<init>(SingleResponse.getInstance(var5.getObjectAt(var3)));
         var2[var3] = var4;
      }

      return var2;
   }

   public X509Extensions getResponseExtensions() {
      return this.data.getResponseExtensions();
   }

   public boolean hasUnsupportedCriticalExtension() {
      Set var1;
      return (var1 = this.getCriticalExtensionOIDs()) != null && !var1.isEmpty();
   }

   public Set getCriticalExtensionOIDs() {
      return this.getExtensionOIDs(true);
   }

   public Set getNonCriticalExtensionOIDs() {
      return this.getExtensionOIDs(false);
   }

   public byte[] getExtensionValue(String oid) {
      X509Extensions var3;
      if ((var3 = this.getResponseExtensions()) != null) {
         X509Extensions var10000 = var3;
         DERObjectIdentifier var5;
         var5 = new DERObjectIdentifier.<init>(oid);
         cn.com.infosec.asn1.x509.X509Extension var6;
         if ((var6 = var10000.getExtension(var5)) != null) {
            ByteArrayOutputStream oid1;
            ByteArrayOutputStream var4 = oid1 = new ByteArrayOutputStream;
            var4.<init>();
            cn.com.infosec.asn1.x509.X509Extension var10002 = var6;
            DEROutputStream var10001 = new DEROutputStream(oid1);

            try {
               var10001.writeObject(var10002.getValue());
               return var4.toByteArray();
            } catch (Exception var2) {
               throw new RuntimeException("error encoding " + var2.toString());
            }
         }
      }

      return null;
   }
}
